summaryrefslogtreecommitdiffstats
path: root/src/mechanics/mechanicssimulation.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/mechanics/mechanicssimulation.h')
-rw-r--r--src/mechanics/mechanicssimulation.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/mechanics/mechanicssimulation.h b/src/mechanics/mechanicssimulation.h
index 9a82d91..f91a159 100644
--- a/src/mechanics/mechanicssimulation.h
+++ b/src/mechanics/mechanicssimulation.h
@@ -76,8 +76,8 @@ protected:
/**
Rigid body with mass, inertia, etc. Collection of mechanics items with
-functionality for moving them about, rotating, etc. Only one mother-tqparent
-(has no tqparent itself, all other items are descendents) allowed.
+functionality for moving them about, rotating, etc. Only one mother-parent
+(has no parent itself, all other items are descendents) allowed.
@short Rigid body, handles MechanicsItems
@author David Saxton
*/
@@ -107,7 +107,7 @@ public:
protected:
/**
* Attempt to find the overall tqparent.
* @returns false iff unsucessful (including if there are no MechanicsItems present)
*/
bool findOverallParent();
@@ -107,7 +107,7 @@ public:
protected:
/**
- * Attempt to find the overall tqparent.
+ * Attempt to find the overall parent.
* @returns false iff unsucessful (including if there are no MechanicsItems present)
*/